( cd usr/lib ; rm -rf libIDL-0.6.so.0 )
( cd usr/lib ; ln -sf libIDL-0.6.so.0.4.4 libIDL-0.6.so.0 )
( cd usr/lib ; rm -rf libIDL.so )
( cd usr/lib ; ln -sf libIDL-0.6.so.0.4.4 libIDL.so )
( cd usr/lib ; rm -rf libIIOP.so )
( cd usr/lib ; ln -sf libIIOP.so.0.5.17 libIIOP.so )
( cd usr/lib ; rm -rf libIIOP.so.0 )
( cd usr/lib ; ln -sf libIIOP.so.0.5.17 libIIOP.so.0 )
( cd usr/lib ; rm -rf libORBit.so )
( cd usr/lib ; ln -sf libORBit.so.0.5.17 libORBit.so )
( cd usr/lib ; rm -rf libORBit.so.0 )
( cd usr/lib ; ln -sf libORBit.so.0.5.17 libORBit.so.0 )
( cd usr/lib ; rm -rf libORBitCosNaming.so )
( cd usr/lib ; ln -sf libORBitCosNaming.so.0.5.17 libORBitCosNaming.so )
( cd usr/lib ; rm -rf libORBitCosNaming.so.0 )
( cd usr/lib ; ln -sf libORBitCosNaming.so.0.5.17 libORBitCosNaming.so.0 )
( cd usr/lib ; rm -rf libORBitutil.so )
( cd usr/lib ; ln -sf libORBitutil.so.0.5.17 libORBitutil.so )
( cd usr/lib ; rm -rf libORBitutil.so.0 )
( cd usr/lib ; ln -sf libORBitutil.so.0.5.17 libORBitutil.so.0 )
# Install the info files for this package
if [ -x usr/bin/install-info ]
then
   usr/bin/install-info --info-dir=/usr/info /usr/info/libIDL.info.gz 2>/dev/null
fi

